extern crate crypto;
extern crate fake;
extern crate rand;
extern crate reqwest;
extern crate rookeries;

use common::crypto::pbkdf2::pbkdf2_simple;
use common::fake::faker::{Faker, Internet, Name};
use common::rand::{thread_rng, Rng};
use common::reqwest::Url;
use common::rookeries::couchdb::Server;
use common::rookeries::User;

use std::default::Default;
use std::env;

pub fn api_base_url() -> Url {
    let server_base_url = match env::var("ROOKERIES_TEST_SERVER") {
        Err(_) => "http://localhost:5000/".to_string(),
        Ok(uri) => uri,
    };
    Url::parse(&server_base_url).unwrap()
}

#[allow(dead_code)]
pub fn valid_user() -> (User, String) {
    let mut test_user = User::default();
    test_user.full_name = <Faker as Name>::name();
    test_user.username = Faker::user_name();
    test_user.profile.email = Faker::safe_email();

    let test_password: String = thread_rng().gen_ascii_chars().take(10).collect();
    test_user.password = pbkdf2_simple(&test_password, 5000).unwrap();

    let couchdb = Server::configure_from_env().unwrap();
    couchdb.update(test_user.clone()).unwrap();

    (test_user, test_password)
}
