extern crate fake;
extern crate regex;
extern crate reqwest;
extern crate rookeries;
#[macro_use]
extern crate serde_json;

use fake::faker::{Faker, Lorem};
use reqwest::{Client, StatusCode};
use rookeries::couchdb::Server;
use rookeries::Page;
use serde_json::Value;

mod common;

const TEST_PAGE_TITLE: &str = "Testing Page";
const TEST_PAGE_CONTENT: &str = r#"
# Hello World
I'm a test page.
"#;

fn test_page() -> Page {
    let mut test_page = Page::default();

    test_page.title = String::from(TEST_PAGE_TITLE);
    test_page.content = String::from(TEST_PAGE_CONTENT);
    test_page.slug = format!("{}", Faker::word());

    let couchdb = Server::configure_from_env().unwrap();
    couchdb.update(test_page.clone()).unwrap();

    test_page
}

#[test]
fn test_serve_page_returns_journal_entry_as_json() {
    let api_base_uri = common::api_base_url();
    let test_client = Client::new();

    let test_page = test_page();

    let page_url = format!("/api/pages/{}", test_page.slug);
    let page_resource_url = api_base_uri.join(&page_url).unwrap();

    let expected_json = json!({
        "slug": test_page.slug,
        "title": TEST_PAGE_TITLE,
        "content": TEST_PAGE_CONTENT,
        "created": Value::Null,
        "links": {"self": page_url}
    });

    let mut actual_response = test_client.get(page_resource_url).send().unwrap();

    assert_eq!(actual_response.status(), StatusCode::Ok);
    let actual_response_json: serde_json::Value = actual_response.json().unwrap();
    assert_eq!(actual_response_json, expected_json);
}

#[test]
fn test_serve_page_view_returns_404_when_no_content_found() {
    let api_base_uri = common::api_base_url();
    let test_client = Client::new();

    let missing_page_url = api_base_uri.join("/api/pages/missing").unwrap();

    let expected_json = json!({
        "error": {
            "status_code": 404,
            "message": "Resource not found.",
            "resource": "/api/pages/missing",
        }
    });

    let mut actual_response = test_client.get(missing_page_url).send().unwrap();

    assert_eq!(actual_response.status(), StatusCode::NotFound);
    let actual_response_json: serde_json::Value = actual_response.json().unwrap();
    assert_eq!(actual_response_json, expected_json);
}
